@@ -1,4 +1,4 @@
-/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -46,7 +46,7 @@ Config::Config()
   this->verbose = 1;
   this->dpi = 300;
   this->guess_dpi = false;
-  this->preferred_page_size = std::make_pair(0, 0);
+  this->preferred_page_size = {0, 0};
   this->use_media_box = false;
   this->bg_subsample = 3;
   this->fg_colors = this->FG_COLORS_DEFAULT;
@@ -72,29 +72,29 @@ namespace string
 
 static void parse_hyperlinks_options(std::string s, Config::Hyperlinks &options)
 {
-  std::vector<std::string> split;
+  std::vector<std::string> items;
   std::replace(s.begin(), s.end(), '_', '-');
-  string::split(s, ',', split);
-  for (const std::string &s : split)
+  string::split(s, ',', items);
+  for (const std::string &item : items)
   {
-    if (s == "border-avis")
+    if (item == "border-avis")
     {
       options.border_always_visible = true;
       continue;
     }
-    else if (s == "no" || s == "none")
+    else if (item == "no" || item == "none")
     {
       options.extract = false;
       continue;
     }
     else if
     (
-      s.length() == 7 &&
-      s[0] == '#' &&
-      s.find_first_not_of("0123456789abcdefABCDEF", 1) == std::string::npos
+      item.length() == 7 &&
+      item[0] == '#' &&
+      item.find_first_not_of("0123456789abcdefABCDEF", 1) == std::string::npos
     )
     {
-      options.border_color = s;
+      options.border_color = item;
       continue;
     }
     throw Config::Error(_("Unable to parse hyperlinks options"));
@@ -106,7 +106,7 @@ static void bad_pages()
   throw Config::Error(_("Unable to parse page numbers"));
 }
 
-static void parse_pages(const std::string &s, std::vector< std::pair<int, int> > &result)
+static void parse_pages(const std::string &s, std::vector<std::pair<int, int>> &result)
 {
   int state = 0;
   int value[2] = { 0, 0 };
@@ -127,7 +127,7 @@ static void parse_pages(const std::string &s, std::vector< std::pair<int, int> >
     {
       if (value[0] < 1 || value[1] < 1 || value[0] > value[1])
         bad_pages();
-      result.push_back(std::make_pair(value[0], value[1]));
+      result.push_back({value[0], value[1]});
       value[0] = value[1] = 0;
       state = 0;
     }
@@ -138,7 +138,7 @@ static void parse_pages(const std::string &s, std::vector< std::pair<int, int> >
     value[1] = value[0];
   if (value[0] < 1 || value[1] < 1 || value[0] > value[1])
     bad_pages();
-  result.push_back(std::make_pair(value[0], value[1]));
+  result.push_back({value[0], value[1]});
 }
 
 static std::pair<int, int>parse_page_size(const std::string &s)
@@ -148,7 +148,7 @@ static std::pair<int, int>parse_page_size(const std::string &s)
   char c;
   stream >> x >> c >> y;
   if (x > 0 && y > 0 && c == 'x' && stream.eof() && !stream.fail())
-    return std::make_pair(x, y);
+    return {x, y};
   else
     throw Config::Error(_("Unable to parse page size"));
 }
@@ -167,7 +167,7 @@ tp string::as(const std::string &s)
   return n;
 }
 
-static unsigned int parse_fg_colors(const std::string &s)
+static int parse_fg_colors(const std::string &s)
 {
   if (s == "web")
     return Config::FG_COLORS_WEB;
@@ -175,21 +175,21 @@ static unsigned int parse_fg_colors(const std::string &s)
     return Config::FG_COLORS_DEFAULT;
   else if (s == "black")
     return Config::FG_COLORS_BLACK;
-  long n = string::as<long>(s);
-  if (n < 1 || n > static_cast<long>(djvu::max_fg_colors))
+  int n = string::as<int>(s);
+  if (n < 1 || n > djvu::max_fg_colors)
     throw Config::Error(string_printf(
-      _("The specified number of foreground colors is outside the allowed range: %u .. %u"),
-      1U, djvu::max_fg_colors
+      _("The specified number of foreground colors is outside the allowed range: %d .. %d"),
+      1, djvu::max_fg_colors
     ));
   return n;
 }
 
-static unsigned int parse_bg_subsample(const std::string &s)
+static int parse_bg_subsample(const std::string &s)
 {
-  long n = string::as<long>(optarg);
-  if (n < 1 || n > static_cast<long>(djvu::max_subsample_ratio))
+  int n = string::as<int>(s);
+  if (n < 1 || n > djvu::max_subsample_ratio)
     throw Config::Error(string_printf(
-      _("The specified subsampling ratio is outside the allowed range: %u .. %u"),
+      _("The specified subsampling ratio is outside the allowed range: %d .. %d"),
       1, djvu::max_subsample_ratio
     ));
   return n;
