@@ -1,4 +1,4 @@
-/* Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
  *
  * This file is part of pdf2djvu.
  *
@@ -41,16 +41,16 @@ djvu::OutlineItem& djvu::Outline::add(std::string description, std::string url)
 size_t djvu::OutlineItem::size() const
 {
     size_t size = 1;
-    for (std::vector<djvu::OutlineItem>::const_iterator it = this->children.begin(); it != this->children.end(); it++)
-        size += it->size();
+    for (const djvu::OutlineItem &child : this->children)
+        size += child.size();
     return size;
 }
 
 size_t djvu::Outline::size() const
 {
     size_t size = 0;
-    for (std::vector<djvu::OutlineItem>::const_iterator it = this->items.begin(); it != this->items.end(); it++)
-        size += it->size();
+    for (const djvu::OutlineItem &item : this->items)
+        size += item.size();
     return size;
 }
 
@@ -59,17 +59,28 @@ static void print_int(std::ostream &stream, size_t value)
 {
     assert(nbits % 8 == 0);
     assert(nbits <= std::numeric_limits<size_t>::digits);
-    if (value >= (1 << nbits))
+    if (value >= static_cast<size_t>(1) << nbits)
         throw djvu::OutlineError();
     for (int i = (nbits / 8) - 1; i >= 0; i--)
-        stream << static_cast<char>((value >> (8 * i)) & 0xff);
+        stream << static_cast<char>((value >> (8 * i)) & 0xFF);
+}
+
+template <int nbits>
+static void print_int_le(std::ostream &stream, size_t value)
+{
+    assert(nbits % 8 == 0);
+    assert(nbits <= std::numeric_limits<size_t>::digits);
+    if (value >= static_cast<size_t>(1) << nbits)
+        throw djvu::OutlineError();
+    for (int i = 0; i < (nbits / 8); i++)
+        stream << static_cast<char>((value >> (8 * i)) & 0xFF);
 }
 
 std::ostream& djvu::operator<<(std::ostream &stream, const djvu::Outline &outline)
 {
     print_int<16>(stream, outline.size());
-    for (std::vector<djvu::OutlineItem>::const_iterator it = outline.items.begin(); it != outline.items.end(); it++)
-        stream << *it;
+    for (const djvu::OutlineItem &item : outline.items)
+        stream << item;
     return stream;
 }
 
@@ -80,13 +91,19 @@ djvu::Outline::operator bool() const
 
 std::ostream& djvu::operator<<(std::ostream &stream, const djvu::OutlineItem &item)
 {
-    print_int<8>(stream, item.children.size());
-    print_int<24>(stream, item.description.size());
+    // DjVu Reference (§8.3.3) says that each bookmark starts with:
+    // • BYTE nChildren — number of immediate child bookmark records
+    // • INT24 nDesc — size of description text
+    // What's actually implemented in DjVuLibre is:
+    // • INT16 (little-endian) nChildren
+    // • INT16 (big-endian) nDesc
+    print_int_le<16>(stream, item.children.size());
+    print_int<16>(stream, item.description.size());
     stream << item.description;
     print_int<24>(stream, item.url.size());
     stream << item.url;
-    for (std::vector<djvu::OutlineItem>::const_iterator it = item.children.begin(); it != item.children.end(); it++)
-        stream << *it;
+    for (const djvu::OutlineItem &child : item.children)
+        stream << child;
     return stream;
 }
 
