@@ -1,4 +1,4 @@
-/* Copyright © 2009-2018 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2009-2019 Jakub Wilk <jwilk@jwilk.net>
  *
  * This file is part of pdf2djvu.
  *
@@ -33,8 +33,13 @@ protected:
     this->process_image(state, width, height);
   }
 
+#if POPPLER_VERSION >= 8200
+  virtual void drawImage(pdf::gfx::State *state, pdf::Object *object, pdf::Stream *stream, int width, int height,
+    pdf::gfx::ImageColorMap *color_map, bool interpolate, const int *mask_colors, bool inline_image)
+#else
   virtual void drawImage(pdf::gfx::State *state, pdf::Object *object, pdf::Stream *stream, int width, int height,
     pdf::gfx::ImageColorMap *color_map, bool interpolate, int *mask_colors, bool inline_image)
+#endif
   {
     this->process_image(state, width, height);
   }
