@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,9 +13,10 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
@@ -23,6 +24,6 @@ class test(case):
         self.require_feature('POSIX')
         self.pdf2djvu('--filter-text', 'tr "a-zA-Z" "n-za-mN-ZA-M"').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^Yberz vcfhz *\n'))
+        r.assert_(stdout=re.compile('^Yberz vcfhz *\n'))
 
 # vim:ts=4 sts=4 sw=4 et
