@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2016 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -20,10 +20,10 @@ from tools import (
 )
 
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issues/115
-    # + introduced in 0.7.1 [3eea6fbdf75b]
-    # + introduced in 0.7.10 [6c155e7cc346]
-    # + fixed in 0.9.3 [369a24e7f845]
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/115
+    # + introduced in 0.7.1 [a9440040faf697bc11370e8012ba586e88e4dca4]
+    # + introduced in 0.7.10 [da7cd2524b329a80581b939037f4d42801f3755d]
+    # + fixed in 0.9.3 [93f9032d99b75145a03ce64de9c3ae3e25314541]
 
     def test(self):
         self.pdf2djvu()
@@ -32,6 +32,6 @@ class test(case):
         r = self.decode(mode='foreground')
         r.assert_(stdout=None)
         colors = count_ppm_colors(r.stdout)
-        assert_greater(colors.get('\xff\0\0', 0), 5000)
+        assert_greater(colors.get('\xFF\0\0', 0), 5000)
 
 # vim:ts=4 sts=4 sw=4 et
