@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -28,78 +28,30 @@ import signal
 import subprocess as ipc
 import sys
 
-import nose
 from nose import SkipTest
 from nose.tools import (
     assert_equal,
+    assert_greater,
+    assert_in,
+    assert_is,
+    assert_is_none,
+    assert_is_not,
+    assert_is_not_none,
+    assert_multi_line_equal,
     assert_not_equal,
+    assert_regexp_matches as assert_regex,
     assert_true,
 )
 
-if not isinstance(b'', str):  # Python 2.6 or 2.7 is required
-    raise RuntimeError('Python 2.6 or 2.7 is required')
+if {0} and not isinstance(b'', str):  # Python 2.7 is required
+    raise RuntimeError('Python 2.7 is required')
 
 re_type = type(re.compile(''))
 
 def assert_fail(msg):
     assert_true(False, msg=msg)  # pylint: disable=redundant-unittest-assert
 
-def noseimport(vmaj, vmin, name=None):
-    def wrapper(f):
-        if sys.version_info >= (vmaj, vmin):
-            return getattr(nose.tools, name or f.__name__)
-        return f
-    return wrapper
-
-@noseimport(2, 7)
-def assert_greater(x, y):
-    assert_true(
-        x > y,
-        msg='{0!r} not greater than {1!r}'.format(x, y)
-    )
-
-@noseimport(2, 7)
-def assert_in(x, c):
-    assert_true(
-        x in c,
-        msg='{0!r} not found in {1!r}'.format(x, c)
-    )
-
-@noseimport(2, 7)
-def assert_is(x, y):
-    assert_true(
-        x is y,
-        msg='{0!r} is not {1!r}'.format(x, y)
-    )
-
-@noseimport(2, 7)
-def assert_is_not(x, y):
-    assert_true(
-        x is not y,
-        msg='{0!r} is {1!r}'.format(x, y)
-    )
-
-@noseimport(2, 7)
-def assert_is_none(obj):
-    assert_is(obj, None)
-
-@noseimport(2, 7)
-def assert_is_not_none(obj):
-    assert_is_not(obj, None)
-
-@noseimport(2, 7)
-def assert_multi_line_equal(x, y):
-    return assert_equal(x, y)
-if sys.version_info >= (2, 7):
-    type(assert_multi_line_equal.__self__).maxDiff = None
-
-@noseimport(2, 7, 'assert_regexp_matches')
-def assert_regex(text, regex):
-    if isinstance(regex, basestring):
-        regex = re.compile(regex)
-    if not regex.search(text):
-        message = "Regex didn't match: {0!r} not found in {1!r}".format(regex.pattern, text)
-        assert_fail(message)
+type(assert_multi_line_equal.__self__).maxDiff = None
 
 def _get_signal_names():
     signame_pattern = re.compile('^SIG[A-Z0-9]*$')
@@ -212,6 +164,7 @@ class case(object):
                 env['LC_ALL'] = _get_locale_for_encoding(value)
                 continue
             raise TypeError('{key!r} is an invalid keyword argument for this function'.format(key=key))
+        env['LANGUAGE'] = 'en'
         print('$', ' '.join(map(pipes.quote, commandline)))
         try:
             child = ipc.Popen(list(commandline),
@@ -380,14 +333,16 @@ def assert_uuid_urn(uuid):
 __all__ = [
     # nose:
     'assert_equal',
-    'assert_not_equal',
-    'assert_true',
+    'assert_greater',
     'assert_in',
     'assert_is',
     'assert_is_none',
+    'assert_is_not',
     'assert_is_not_none',
     'assert_multi_line_equal',
+    'assert_not_equal',
     'assert_regex',
+    'assert_true',
     # misc assert:
     'assert_fail',
     # helper classes:
