@@ -106,7 +106,7 @@ std::string xmp::transform(const std::string &ibytes, const pdf::Metadata &metad
     std::string now_date = pdf::Timestamp::now().format('T');
     data["Xmp.xmp.MetadataDate"] = now_date;
     if (data.findKey(Exiv2::XmpKey("Xmp.xmpMM.History")) == data.end()) {
-        Exiv2::Value::AutoPtr empty_seq = Exiv2::Value::create(Exiv2::xmpSeq);
+        auto empty_seq = Exiv2::Value::create(Exiv2::xmpSeq);
         data.add(Exiv2::XmpKey("Xmp.xmpMM.History"), empty_seq.get());
     }
     data["Xmp.xmpMM.InstanceID"] = instance_id;
